@@ -75,11 +75,18 @@ class manage(Command):
             action="store_true",
             default=True,
             help="Use production settings (default)")
+        try:
+            instance_name = os.environ["LAVA_INSTANCE"]
+        except KeyError:
+            try:
+                instance_name = os.path.basename(os.environ["VIRTUAL_ENV"])
+            except KeyError:
+                instance_name = None
         group.add_argument(
             "-i", "--instance",
             action="store",
-            default=None,
-            help="Use the specified instance (works only with --production)")
+            default=instance_name,
+            help="Use the specified instance (works only with --production, default %(default)s)")
         group.add_argument(
             "-I", "--instance-template",
             action="store",
